@@ -5,7 +5,7 @@
 // <Ilya.Skriblovsky@gmail.com>
 //
 
-// $Id: Settings.h 105 2010-07-06 10:59:53Z mitrandir $
+// $Id: Settings.h 124 2010-07-27 11:27:25Z mitrandir $
 
 // Settings - loads and provides settings from configuration file
 
@@ -40,6 +40,8 @@ class Settings
         char *_borderColor;
         char *_borderActiveColor;
 
+        char *_brokenPatternFilename;
+
         int _borderWidth;
         int _textLeftMargin;
         int _textRightMargin;
@@ -89,6 +91,8 @@ class Settings
         char* borderColor() { return _borderColor; }
         char* borderActiveColor() { return _borderActiveColor; }
 
+        const char *brokenPatternFilename() { return _brokenPatternFilename; }
+
         int borderWidth() { return _borderWidth; }
         int textLeftMargin() { return _textLeftMargin; }
         int textRightMargin() { return _textRightMargin; }
