@@ -5,7 +5,7 @@
 // <Ilya.Skriblovsky@gmail.com>
 //
 
-// $Id: TeleWindow.cpp 124 2010-07-27 11:27:25Z mitrandir $
+// $Id: TeleWindow.cpp 127 2010-07-27 17:22:21Z mitrandir $
 
 #include "TeleWindow.h"
 
@@ -853,7 +853,7 @@ void TeleWindow::setNewSize(int width, int height)
     _width = width;
     _height = height;
 
-    XResizeWindow(_dpy, _win, _width, _height);
+    XMoveResizeWindow(_dpy, _win, 0, 0, _width, _height);
 
     recreateBufferPixmap();
 
