@@ -5,7 +5,7 @@
 // <Ilya.Skriblovsky@gmail.com>
 //
 
-// $Id: XTools.cpp 102 2010-06-29 13:20:56Z mitrandir $
+// $Id: XTools.cpp 124 2010-07-27 11:27:25Z mitrandir $
 
 #include "XTools.h"
 
@@ -18,12 +18,17 @@
 #include <X11/extensions/Xrender.h>
 #include <X11/extensions/Xdamage.h>
 
+#include <Imlib2.h>
+
 
 Display* XTools::_dpy = 0;
 
 int XTools::_damage_event_base = 0;
 int XTools::_damage_error_base = 0;
 
+int XTools::_xrender_event_base = 0;
+int XTools::_xrender_error_base = 0;
+
 XTools::ErrorHandler XTools::_prevErrorHandler;
 
 Atom XTools::_NET_CLIENT_LIST;
@@ -40,6 +45,7 @@ Atom XTools::_NET_SHOWING_DESKTOP;
 Atom XTools::_NET_CLOSE_WINDOW;
 Atom XTools::WM_STATE;
 Atom XTools::WM_NAME;
+Atom XTools::_NET_WM_ICON;
 
 
 #define INIT_ATOM(dpy, ATOMNAME)        ATOMNAME = XInternAtom((dpy), #ATOMNAME, 0L)
@@ -62,8 +68,7 @@ void XTools::init(Display *dpy)
     INIT_ATOM(dpy, _NET_CLOSE_WINDOW);
     INIT_ATOM(dpy, WM_STATE);
     INIT_ATOM(dpy, WM_NAME);
-
-    checkDamageExtension();
+    INIT_ATOM(dpy, _NET_WM_ICON);
 
     _prevErrorHandler = XSetErrorHandler(errorHandler);
 }
@@ -198,6 +203,15 @@ bool XTools::checkDamageExtension()
 }
 
 
+bool XTools::checkXRenderExtension()
+{
+    if (! XRenderQueryExtension(_dpy, &_xrender_event_base, &_xrender_error_base))
+        return false;
+
+    return true;
+}
+
+
 void XTools::enableCompositeRedirect()
 {
     for (int i = 0; i < ScreenCount(_dpy); i++)
@@ -412,3 +426,80 @@ XRenderPictFormat* XTools::xrenderRGBAFormat()
 
     return rgbaFormat;
 }
+
+
+
+bool XTools::fetchWindowIconFromProperty(
+        Window window,
+        int *width, int *height,
+        Pixmap *pixmap,
+        Picture *picture
+    )
+{
+    if (width) *width = 0;
+    if (height) *height = 0;
+    if (pixmap) *pixmap = 0;
+    if (picture) *picture = 0;
+
+    Atom real_type;
+    int real_format;
+    unsigned long items_read, items_left;
+
+    unsigned int *iconData;
+
+    if (XGetWindowProperty(_dpy, window, _NET_WM_ICON, 0, 8192L, False,
+            XA_CARDINAL, &real_type, &real_format, &items_read, &items_left,
+            (unsigned char **)&iconData) == Success && items_read > 0)
+    {
+        int w = iconData[0];
+        int h = iconData[1];
+
+        if (width) *width = w;
+        if (height) *height = h;
+
+        if (pixmap)
+        {
+            Imlib_Image icon = imlib_create_image_using_data( w, h, &iconData[2]);
+            imlib_context_set_image(icon);
+            imlib_image_set_has_alpha(1);
+
+            *pixmap = XCreatePixmap(_dpy, RootWindow(_dpy, DefaultScreen(_dpy)), w, h, 32);
+
+            imlib_context_set_display(_dpy);
+            imlib_context_set_visual(rgbaVisual()->visual);
+            imlib_context_set_colormap(DefaultColormap(_dpy, DefaultScreen(_dpy)));
+            imlib_context_set_drawable(*pixmap);
+
+            // Making image with premultiplied alpha
+            Imlib_Image premul = imlib_create_image(w, h);
+            imlib_context_set_image(premul);
+            imlib_image_set_has_alpha(1);
+            imlib_context_set_color(0, 0, 0, 255);
+            imlib_context_set_blend(0);
+            imlib_image_fill_rectangle(0, 0, w, h);
+            imlib_context_set_blend(1);
+            imlib_blend_image_onto_image(icon, 0, 0, 0, w, h, 0, 0, w, h);
+            imlib_image_copy_alpha_to_image(icon, 0, 0);
+
+            imlib_context_set_blend(0);
+            imlib_render_image_on_drawable(0, 0);
+
+            imlib_free_image();
+            imlib_context_set_image(icon);
+            imlib_free_image();
+
+            if (picture)
+            {
+                *picture = XRenderCreatePicture(_dpy, *pixmap,
+                    xrenderRGBAFormat(), 0, 0
+                );
+            }
+        }
+
+        XFree((unsigned char*)iconData);
+
+        return true;
+    }
+
+    return false;
+}
