@@ -5,7 +5,7 @@
 // <Ilya.Skriblovsky@gmail.com>
 //
 
-// $Id: XTools.h 102 2010-06-29 13:20:56Z mitrandir $
+// $Id: XTools.h 124 2010-07-27 11:27:25Z mitrandir $
 
 // XTools - various utility functions for X11
 
@@ -25,6 +25,9 @@ class XTools
         static int _damage_event_base;
         static int _damage_error_base;
 
+        static int _xrender_event_base;
+        static int _xrender_error_base;
+
         typedef int (*ErrorHandler)(Display *display, XErrorEvent *event);
         static ErrorHandler _prevErrorHandler;
 
@@ -43,6 +46,7 @@ class XTools
         static Atom _NET_CLOSE_WINDOW;
         static Atom WM_STATE;
         static Atom WM_NAME;
+        static Atom _NET_WM_ICON;
 
         static void init(Display *dpy);
 
@@ -53,6 +57,7 @@ class XTools
         static char* windowTitle_alloc(Window window);
         static char* windowClass_alloc(Window window);
 
+        static bool checkXRenderExtension();
         static bool checkCompositeExtension();
         static bool checkDamageExtension();
 
@@ -82,6 +87,13 @@ class XTools
         static XRenderPictFormat* xrenderFormat();
         static XRenderPictFormat* xrenderRGBAFormat();
         static const XVisualInfo* rgbaVisual();
+
+        static bool fetchWindowIconFromProperty(
+            Window window,
+            int *width, int *height,
+            Pixmap *pixmap,
+            Picture *picture
+        );
 };
 
 #endif
